==> vivotek_3.0.2.0.tar.gz: www/index3.js <==
$(function () {

	var saveopts = ["SD", "Camera"];
	var schopts = ["Minute", "Hour", "Day", "Week", "Month"];
	var dayweek = ["Monday", "Tuesday", "Wednesday", "Thrusday", "Friday", "Saturday", "Sunday"];

	var fentitat = $("#TxPlate").dxTextBox();

	$("#radio-group-simple").dxRadioGroup({
		items: saveopts,
		value: saveopts[0],
		layout: "horizontal"
	});

	$("#rg-freq").dxRadioGroup({
		items: schopts,
		value: schopts[0],
		layout: "horizontal",
		onValueChanged: function (e) {
			if (e.value == "Minute") {

				document.getElementById('minutediv').style.visibility = 'visible';
				document.getElementById('minutediv').style.display = 'block';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';

			} else if (e.value == "Hour") {
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'visible';
				document.getElementById('minutehourdiv').style.display = 'block';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			} else if (e.value == "Day") {
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'visible';
				document.getElementById('datedaydiv').style.display = 'block';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			} else if (e.value == "Week") {
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'visible';
				document.getElementById('dayweekdiv').style.display = 'block';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			} else if (e.value == "Month") {
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'visible';
				document.getElementById('daymonthdiv').style.display = 'block';
			}

		}
	});
	
	$("#SendXML").dxCheckBox({
		text: "Send XML"
    });
	
	$("#SendJSON").dxCheckBox({
		text: "Send JSON"
    });
	
	$("#SAVESD").dxCheckBox({
		text: "Save to SD card"
    });
	

	$("#clear").dxDateBox({
		type: "time",
		value: new Date(2015, 11, 1, 1)
	});

	$("#MINUTE").dxNumberBox({
		value: 1,
		min: 1,
		max: 50000000,
		showSpinButtons: true
	});
	$("#MINUTEHOUR").dxNumberBox({
		value: 0,
		min: 0,
		max: 59,
		showSpinButtons: true
	});

	$("#DATEDAY").dxDateBox({
		type: "time",
		value: new Date(2015, 11, 1, 1)
	});

	$("#HOURWEEK").dxDateBox({
		type: "time",
		value: new Date(2015, 11, 1, 1)
	});

	$("#DAYWEEK").dxRadioGroup({
		items: dayweek,
		value: dayweek[0],
		layout: "horizontal"
	});

	$("#DAYMONTH").dxNumberBox({
		value: 1,
		min: 1,
		max: 31,
		showSpinButtons: true
	});

	$("#HOURMONTH").dxDateBox({
		type: "time",
		value: new Date(2015, 11, 1, 1)
	})

	$("#ROITOP").dxNumberBox({
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#ROILEFT").dxNumberBox({
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#ROIWIDTH").dxNumberBox({
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#ROIHEIGHT").dxNumberBox({
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});

	$("#icon-done_info").dxButton({
		icon: "check",
		type: "success",
		text: "Save"
	});

});

==> vivotek_4.6.0.51.tar.gz: www/index3.js <==
$(function()
{
	var saveopts = ["SD", "Camera"];
	var schopts = ["Minute", "Hour", "Day", "Week", "Month"];
	var dayweek = ["Monday", "Tuesday", "Wednesday", "Thrusday", "Friday", "Saturday", "Sunday"];
	var fentitat = $("#TxPlate").dxTextBox();
	$("#radio-group-simple").dxRadioGroup(
	{
		items: saveopts,
		value: saveopts[0],
		layout: "horizontal"
	});
	$("#rg-freq").dxRadioGroup(
	{
		items: schopts,
		value: schopts[0],
		layout: "horizontal",
		onValueChanged: function(e)
		{
			if (e.value == "Minute")
			{
				document.getElementById('minutediv').style.visibility = 'visible';
				document.getElementById('minutediv').style.display = 'block';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			}
			else if (e.value == "Hour")
			{
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'visible';
				document.getElementById('minutehourdiv').style.display = 'block';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			}
			else if (e.value == "Day")
			{
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'visible';
				document.getElementById('datedaydiv').style.display = 'block';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			}
			else if (e.value == "Week")
			{
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'visible';
				document.getElementById('dayweekdiv').style.display = 'block';
				document.getElementById('daymonthdiv').style.visibility = 'hidden';
				document.getElementById('daymonthdiv').style.display = 'none';
			}
			else if (e.value == "Month")
			{
				document.getElementById('minutediv').style.visibility = 'hidden';
				document.getElementById('minutediv').style.display = 'none';
				document.getElementById('minutehourdiv').style.visibility = 'hidden';
				document.getElementById('minutehourdiv').style.display = 'none';
				document.getElementById('datedaydiv').style.visibility = 'hidden';
				document.getElementById('datedaydiv').style.display = 'none';
				document.getElementById('dayweekdiv').style.visibility = 'hidden';
				document.getElementById('dayweekdiv').style.display = 'none';
				document.getElementById('daymonthdiv').style.visibility = 'visible';
				document.getElementById('daymonthdiv').style.display = 'block';
			}
		}
	});
	$("#SendXML").dxCheckBox(
	{
		text: "Send XML"
	});
	$("#SendJSON").dxCheckBox(
	{
		text: "Send JSON"
	});
	$("#SAVESD").dxCheckBox(
	{
		text: "Save to SD card"
	});
	$("#clear").dxDateBox(
	{
		type: "time",
		value: new Date(2015, 11, 1, 1)
	});
	$("#MINUTE").dxNumberBox(
	{
		value: 1,
		min: 1,
		max: 50000000,
		showSpinButtons: true
	});
	$("#MINUTEHOUR").dxNumberBox(
	{
		value: 0,
		min: 0,
		max: 59,
		showSpinButtons: true
	});
	$("#DATEDAY").dxDateBox(
	{
		type: "time",
		value: new Date(2015, 11, 1, 1)
	});
	$("#HOURWEEK").dxDateBox(
	{
		type: "time",
		value: new Date(2015, 11, 1, 1)
	});
	$("#DAYWEEK").dxRadioGroup(
	{
		items: dayweek,
		value: dayweek[0],
		layout: "horizontal"
	});
	$("#DAYMONTH").dxNumberBox(
	{
		value: 1,
		min: 1,
		max: 31,
		showSpinButtons: true
	});
	$("#HOURMONTH").dxDateBox(
	{
		type: "time",
		value: new Date(2015, 11, 1, 1)
	})
	$("#ROITOP").dxNumberBox(
	{
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#ROILEFT").dxNumberBox(
	{
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#ROIWIDTH").dxNumberBox(
	{
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#ROIHEIGHT").dxNumberBox(
	{
		value: 0,
		min: 0,
		max: 5000,
		showSpinButtons: true
	});
	$("#icon-done_info").dxButton(
	{
		icon: "check",
		type: "success",
		text: "Save"
	});
});
